@@ -9,6 +9,8 @@ from sorl.thumbnail.admin import AdminImageMixin
 from coop.utils.autocomplete_admin import FkAutocompleteAdmin, NoLookupsFkAutocompleteAdmin
 from django.db.models.loading import get_model
 from chosen import widgets as chosenwidgets
+from coop.doc.admin import AttachmentsInline
+from coop.link.admin import LinksInline
 
 if "coop.agenda" in settings.INSTALLED_APPS:
     from coop.agenda.admin import DatedInline
@@ -22,6 +24,12 @@ if "coop_cms" in settings.INSTALLED_APPS:
 
     class MyNavTreeAdmin(NavTreeAdmin):
         change_form_template = 'admin/navtree_change_form.html'
+        # list_display = ['__unicode__', 'name', 'sites']
+        # list_editable = ['name', 'sites']
+
+        # if settings.COOP_USE_SITES:
+        #     list_display.append('sites')
+        #     list_display.append('sites')
 
     navtree_model = get_navTree_class()
     admin.site.unregister(navtree_model)
@@ -60,16 +68,18 @@ if "coop_cms" in settings.INSTALLED_APPS:
         readonly_fields = []
         fieldsets = (
             #(_('Navigation'), {'fields': ('navigation_parent',)}),
-            ('Edition', {'fields': ['title', 'logo', 'content', 
+            ('Edition', {'fields': ['title', 'logo', 'summary','content', 
                                     'organization', 'remote_organization_label', 'remote_organization_uri',
                                     'person', 'remote_person_label', 'remote_person_uri']}),
-            ('Options', {'fields': ('summary', 'category', 'template', 'is_homepage', 'in_newsletter', 'isSection')}),
+            ('Options', {'fields': ('category', 'template', 'headline', 'in_newsletter', 'isSection', 'display_dates',)}),
         )
         related_search_fields = {'organization': ('title', 'subtitle', 'description'), 
                                  'person': ('first_name', 'last_name',), }
 
         if "coop.agenda" in settings.INSTALLED_APPS:
-            inlines = [DatedInline]
+            inlines = [DatedInline, AttachmentsInline, LinksInline]
+        else:
+            inlines = [AttachmentsInline, LinksInline]
 
         if settings.COOP_USE_SITES:
             fieldsets[0][1]['fields'].insert(0, 'sites')
