@@ -1,10 +1,14 @@
 # -*- coding:utf-8 -*-
 from django.conf import settings
+
+
 if 'haystack' in settings.INSTALLED_APPS:
+    import logging
     from haystack import indexes
     from coop_local.models import Organization, Exchange, Article, Event
+    from django.contrib.sites.models import Site
 
-
+    log = logging.getLogger('coop')
 
     if getattr(settings, 'HAYSTACK_REALTIME', False):
         Indexes = indexes.RealTimeSearchIndex
@@ -28,7 +32,7 @@ if 'haystack' in settings.INSTALLED_APPS:
             return [u"%s" % tag.name for tag in obj.tags.all()]
 
         def prepare(self, obj):
-            print "prepare id=%s %s" % (obj.id, obj)
+            log.debug("prepare id=%s %s" % (obj.id, obj))
             prepared_data = super(CoopIndex, self).prepare(obj)
 
             prepared_data['text'] = prepared_data['text'] + ' ' + \
@@ -36,23 +40,13 @@ if 'haystack' in settings.INSTALLED_APPS:
             return prepared_data
 
 
-    # The main class
-    class CoopIndexWithoutSite(Indexes):
-        text = indexes.CharField(document=True, use_template=True)
-        tags = indexes.MultiValueField(boost=1.2, faceted=True)
-        # modified = indexes.DateField(model_attr='modified', faceted=True)
-        rendered = indexes.CharField(use_template=True, indexed=False)
+    # Used in multisites cases. The point is if a model doesn't have a 'sites' fields
+    # thus add all sites in the sites field
+    class CoopIndexWithoutSite(CoopIndex):
 
-        def prepare_tags(self, obj):
-            return [u"%s" % tag.name for tag in obj.tags.all()]
+        def prepare_sites(self, obj):
+            return [u"%s" % site.domain for site in Site.objects.all()]
 
-        def prepare(self, obj):
-            print "prepare id=%s %s" % (obj.id, obj)
-            prepared_data = super(CoopIndexWithoutSite, self).prepare(obj)
-
-            prepared_data['text'] = prepared_data['text'] + ' ' + \
-            ' '.join(prepared_data['tags']) 
-            return prepared_data
 
 
     class OrganizationIndex(CoopIndex):
