@@ -4,6 +4,7 @@ from django.conf.urls.defaults import patterns, include, url
 from django.views.generic.base import TemplateView, RedirectView
 from django.conf import settings
 from coop.feeds import UpdateFeed
+from django.contrib.sites.models import Site
 
 
 class TextPlainView(TemplateView):
@@ -38,7 +39,8 @@ urlpatterns = patterns('',
     # url(r'^d2r/(?P<mode>[\w-]+)/mapping.ttl$', 'coop.views.d2r_mapping'),
 
     url(r'^communes/$', 'coop.views.communes'),
-    url(r'^geojson/', 'coop.views.geojson'),
+    url(r'^geojson/(?P<model>[\w-]+)', 'coop.views.geojson'),
+    url(r'^geojson/', 'coop.views.geojson_amap'),
 
 )
 
@@ -52,17 +54,23 @@ if 'coop.webid' in settings.INSTALLED_APPS:
         (r'^webid/', include('coop.webid.urls')),
 )
 
+if 'coop.doc' in settings.INSTALLED_APPS:
+    urlpatterns = urlpatterns + patterns('',
+        (r'^doc/', include('coop.doc.urls')),
+)
+
 
 if 'haystack' in settings.INSTALLED_APPS:
     # minimal version
     from haystack.views import search_view_factory
     from haystack.forms import SearchForm
     from coop.forms import SiteSearchForm
-    from coop.views import ModelSearchView
+    from coop.views import ModelSearchView, SiteModelSearchView
     urlpatterns += patterns('haystack.views',
         url(r'^search/search/$', search_view_factory(
-            view_class=ModelSearchView,
+            view_class=SiteModelSearchView,
             form_class=SiteSearchForm,
+            site=Site.objects.get_current(),
             template='search/search.html',
             load_all=False
         ), name='haystack_search'),
